@@ -180,6 +180,8 @@ class MiniRpaManager(MiniRpaFunction):
                 elif function_name == 'download_excel_by_context_click':
                     sap_automation.download_excel_by_context_click(sap_operation_dict['column_name'], sap_operation_dict['context_menu_item_name'],
                                                                    sap_operation_dict['file_name'])
+                elif function_name == 'context_click_in_table':
+                    sap_automation.context_click_in_table(sap_operation_dict['column_name'], sap_operation_dict['context_menu_item_name'])
                 elif function_name == 'download_excel_by_menu_click':
                     sap_automation.download_excel_by_menu_click(sap_operation_dict['file_name'])
                 elif function_name == 'download_excel_by_views_button_click':
@@ -525,6 +527,23 @@ class MiniRpaManager(MiniRpaFunction):
             self.prepare_file_name_suffix()
             delivery_type = self.delivery_dict['process_name']
 
+            from_server_name = self.delivery_dict.get('from_server_name', '')
+            from_share_name = self.delivery_dict.get('from_share_name', '')
+            from_folder_path = self.replace_variables_in_string(self.delivery_dict.get('from_folder_path', ''))
+            from_file_name = self.prepare_file_name(self.delivery_dict.get('from_file_name', ''))
+
+            update_server_name = self.delivery_dict.get('update_server_name', '')
+            update_share_name = self.delivery_dict.get('update_share_name', '')
+            update_folder_path = self.replace_variables_in_string(self.delivery_dict.get('update_folder_path', ''))
+            update_file_name = self.prepare_file_name(self.delivery_dict.get('update_file_name', ''))
+
+            from_server_name = from_server_name if from_server_name else self.server_name
+            from_share_name = from_share_name if from_share_name else self.share_name
+            from_folder_path = from_folder_path if from_folder_path else self.report_save_path
+            update_server_name = update_server_name if update_server_name else self.server_name
+            update_share_name = update_share_name if update_share_name else self.share_name
+            update_folder_path = update_folder_path if update_folder_path else self.report_save_path
+
             print(f'---------- current process name {delivery_type} ----------')
 
             if delivery_type == 'send_email':
@@ -546,7 +565,6 @@ class MiniRpaManager(MiniRpaFunction):
                 email_bcc = email_values['email_bcc'].split(';')
                 # attachment_name_list = [self.prepare_file_name(file_name) for file_name in attachment_name_list]
                 self.send_email(email_account, email_password, email_address, email_body, email_header, email_subject, email_to, email_cc, attachment_name_list, email_bcc)
-
             if delivery_type == 'hrs_send_email_by_file_name':
                 # error_log_folder_path is the path on the server rather than the remote folder path
                 email_fields = ['email_account', 'email_password', 'email_address', 'email_body', 'email_header', 'email_subject', 'email_cc', 'email_bcc', 'file_name']
@@ -573,7 +591,6 @@ class MiniRpaManager(MiniRpaFunction):
                                 attachment_name_list = [file_name]
                                 executor.submit(self.send_email, email_account, email_password, email_address, email_body, email_header, email_subject, email_to, email_cc,
                                                 attachment_name_list, email_bcc)
-
             elif delivery_type == 'send_anniversary_email':
                 email_fields = ['card_type', 'email_account', 'email_password', 'email_address', 'email_header', 'email_subject', 'email_cc', 'anniversary_file_name',
                                 'template_folder_path', 'email_to_manager_column', 'manager_name_column', 'anniversary_year_column', 'email_to_column', 'user_name_column']
@@ -600,7 +617,6 @@ class MiniRpaManager(MiniRpaFunction):
                 hrs_send_anniversary_email(card_type, anniversary_year_column, email_to_column, user_name_column, email_cc,
                                            email_subject, email_header, email_account, email_password, email_address, anniversary_file_path, template_folder_path,
                                            birthday_year, self.user_name, self.user_password, self.server_name, self.share_name, self.port)
-
             elif delivery_type == 'save_file_to_fixed_folder':
                 original_folder_path = self.replace_variables_in_string(self.delivery_dict.get('original_folder_path', '').strip())
                 original_file_name = self.prepare_file_name(self.delivery_dict.get('original_file_name', ''))
@@ -613,10 +629,6 @@ class MiniRpaManager(MiniRpaFunction):
                 if not delivery_folder_path:
                     delivery_folder_path = self.report_save_path
 
-                # delivery_file_name = self.prepare_file_name(self.delivery_dict.get('file_name', ''))
-                # delivery_file_path = self.delivery_dict.get('delivery_file_path', '')
-                # original_file_path = self.report_save_path + os.sep + delivery_file_name
-
                 original_file_path = original_folder_path + os.sep + original_file_name
                 delivery_file_path = delivery_folder_path + os.sep + delivery_file_name
 
@@ -625,47 +637,47 @@ class MiniRpaManager(MiniRpaFunction):
                 smb_store_remote_file_by_obj(self.user_name, self.user_password, self.server_name, self.share_name, delivery_file_path, file_obj, self.port)
                 print(f'-----{original_file_path} is copied successfully!-----')
             elif delivery_type == 'upload_file_by_api':
-                api_fields = ['api', 'api_add_token', 'api_token', 'api_bearer', 'file_name']
-                api_values = {field: self.delivery_dict.get(field, False if field == 'api_add_token' else '') for field in api_fields}
+                api_fields = ['api', 'api_add_token', 'api_token', 'api_bearer', 'file_name', 'use_proxy']
+                api_values = {field: self.delivery_dict.get(field, False if field in ['api_add_token', 'use_proxy'] else '')
+                              for field in api_fields}
 
                 api = api_values['api']
                 api_add_token = api_values['api_add_token']
                 api_token = api_values['api_token']
                 api_bearer = api_values['api_bearer']
+                use_proxy = api_values['use_proxy']
                 api_file_name = self.prepare_file_name(api_values['file_name'])
                 api_file_path = self.report_save_path + os.sep + api_file_name
-                self.upload_file_by_api(api_file_path, api, api_add_token, api_token, api_bearer)
+                self.upload_file_by_api(api_file_path, api, api_add_token, api_token, api_bearer, use_proxy)
             elif delivery_type == 'clear_existed_files':
                 report_save_path = self.replace_variables_in_string(self.delivery_dict.get('report_save_path', ''))
                 exception_str = self.delivery_dict.get('exception_str', '')
                 report_save_path = report_save_path if report_save_path else self.report_save_path
                 exception_str = exception_str if exception_str else 'Common'
                 self.clear_existed_files(report_save_path, exception_str)
-
             elif delivery_type == 'clear_existed_files_by_keywords':
                 report_save_path = self.replace_variables_in_string(self.delivery_dict.get('report_save_path', ''))
                 deletion_keyword = self.delivery_dict.get('deletion_keyword', '')
                 report_save_path = report_save_path if report_save_path else self.report_save_path
                 deletion_keyword = deletion_keyword if deletion_keyword else ''
                 self.clear_existed_files_by_keywords(report_save_path, deletion_keyword)
-
             elif delivery_type == 'copy_file_cross_public_folders':
-                from_server_name = self.delivery_dict.get('from_server_name', '')
-                from_share_name = self.delivery_dict.get('from_share_name', '')
-                from_folder_path = self.replace_variables_in_string(self.delivery_dict.get('from_folder_path', ''))
-                from_file_name = self.prepare_file_name(self.delivery_dict.get('from_file_name', ''))
-
-                update_server_name = self.delivery_dict.get('update_server_name', '')
-                update_share_name = self.delivery_dict.get('update_share_name', '')
-                update_folder_path = self.replace_variables_in_string(self.delivery_dict.get('update_folder_path', ''))
-                update_file_name = self.prepare_file_name(self.delivery_dict.get('update_file_name', ''))
-
-                from_server_name = from_server_name if from_server_name else self.server_name
-                from_share_name = from_share_name if from_share_name else self.share_name
-                from_folder_path = from_folder_path if from_folder_path else self.report_save_path
-                update_server_name = update_server_name if update_server_name else self.server_name
-                update_share_name = update_share_name if update_share_name else self.share_name
-                update_folder_path = update_folder_path if update_folder_path else self.report_save_path
+                # from_server_name = self.delivery_dict.get('from_server_name', '')
+                # from_share_name = self.delivery_dict.get('from_share_name', '')
+                # from_folder_path = self.replace_variables_in_string(self.delivery_dict.get('from_folder_path', ''))
+                # from_file_name = self.prepare_file_name(self.delivery_dict.get('from_file_name', ''))
+                #
+                # update_server_name = self.delivery_dict.get('update_server_name', '')
+                # update_share_name = self.delivery_dict.get('update_share_name', '')
+                # update_folder_path = self.replace_variables_in_string(self.delivery_dict.get('update_folder_path', ''))
+                # update_file_name = self.prepare_file_name(self.delivery_dict.get('update_file_name', ''))
+                #
+                # from_server_name = from_server_name if from_server_name else self.server_name
+                # from_share_name = from_share_name if from_share_name else self.share_name
+                # from_folder_path = from_folder_path if from_folder_path else self.report_save_path
+                # update_server_name = update_server_name if update_server_name else self.server_name
+                # update_share_name = update_share_name if update_share_name else self.share_name
+                # update_folder_path = update_folder_path if update_folder_path else self.report_save_path
 
                 self.copy_file_cross_public_folders(from_server_name, from_share_name, from_folder_path, from_file_name, update_server_name, update_share_name, update_folder_path,
                                                     update_file_name)
@@ -675,6 +687,19 @@ class MiniRpaManager(MiniRpaFunction):
                 api_credential = self.delivery_dict.get('api_credential', '')
                 self.trigger_python_bot_task(bot_url, api_credential)
 
+            elif delivery_type == 'upload_file_to_sharepoint':
+                # from_folder_path = self.replace_variables_in_string(self.delivery_dict.get('from_folder_path', ''))
+                # from_file_name = self.prepare_file_name(self.delivery_dict.get('from_file_name', ''))
+                sharepoint_site_url = self.delivery_dict.get('sharepoint_site_url', '')
+                sharepoint_folder_url = self.delivery_dict.get('sharepoint_folder_url', '')
+                sharepoint_file_name = self.prepare_file_name(self.delivery_dict.get('sharepoint_file_name', ''))
+                self.upload_file_to_sharepoint(from_folder_path, from_file_name, sharepoint_site_url, sharepoint_folder_url, sharepoint_file_name)
+            elif delivery_type == 'batch_copy_files_within_public_folders':
+                file_key_word = self.delivery_dict.get('file_key_word', '')
+                copy_mode = self.delivery_dict.get('copy_mode', 'contain_key_word')
+                self.batch_copy_files_within_public_folders(from_server_name, from_share_name, from_folder_path, file_key_word, update_server_name, update_share_name,
+                                                            update_folder_path, copy_mode)
+
         if self.process_database:
             database_config_dict = {
                 'user_name': self.user_name,
