@@ -535,17 +535,18 @@ class MiniRpaSapAutomation:
         self.web_rpa.press_keyboard_shortcut(shortcut_list)
         sleep(5)
 
+        skip_download_process = False
         self.web_rpa.wait_element_presence_by_css_selector(SAP_LOGO_CSS_SELECTOR)
         message_elements = self.web_rpa.browser.find_elements(By.CSS_SELECTOR, "div[id$='contentdiv'][id^='userarealist'] div:first-child")
         if message_elements:
             for message_element in message_elements:
                 if 'Report contains no data' in message_element.text.strip():
-                    self.skip_download_process = True
+                    skip_download_process = True
                     print(f'No data found: {file_name}')
                     sleep(3)
                     break
 
-        if not self.skip_download_process:
+        if not skip_download_process:
             sleep(1)
             self.web_rpa.input_y01f_download_excel_file_name(file_name, True, self.user_name, self.user_password, self.server_name, self.share_name, self.report_save_path)
 
@@ -877,6 +878,7 @@ class MiniRpaSapAutomation:
         for split_element_index, split_element in enumerate(y01k_split_elements):
             if split_element_index + 1 == split_element_order:
                 self.web_rpa.drag_by_offset(split_element, 0, y_offset)
+                sleep(3)
                 break
 
     def input_sm35_session_name(self, input_index, session_name):
